@@ -57,15 +57,15 @@ public:
 
     KToolTipWidget *tooltip;
     QWidget* view;
-    QAbstractItemModel *model;
+    const QAbstractItemModel *model;
     QTimer* timer;
-    QModelIndex item;
+    QPersistentModelIndex item;
     QRect itemRect;
     int delay;
     ToolTipPosition toolTipPosition;
 };
 
-ToolTipManager::ToolTipManager(QAbstractItemModel *model, QWidget* parent, ToolTipPosition toolTipPosition)
+ToolTipManager::ToolTipManager(const QAbstractItemModel *model, QWidget* parent, ToolTipPosition toolTipPosition)
     : QObject(parent)
     , d(new ToolTipManager::Private)
 {
@@ -88,6 +88,16 @@ ToolTipManager::~ToolTipManager()
     delete d;
 }
 
+void ToolTipManager::setModel(const QAbstractItemModel *model)
+{
+    d->model = model;
+}
+
+const QAbstractItemModel *ToolTipManager::model() const
+{
+    return d->model;
+}
+
 bool ToolTipManager::eventFilter(QObject* watched, QEvent* event)
 {
     if (watched == d->view) {
